<template>
  <div class="fullheight">
    <div style="display: flex">
      <el-form
        ref="searchForm"
        :model="searchForm"
        label-width="80px"
        class="searchTop"
      >
        <el-input
          v-model="searchForm.rummager"
          placeholder="请输入检查人"
          clearable
          style="margin-right:10px;margin-bottom:5px"
        >
        </el-input>
        <el-date-picker
          v-model="searchForm.checkDate"
          type="date"
          placeholder="请选择检查日期"
          format="yyyy-MM-dd"
          value-format="yyyy-MM-dd"
        >
        </el-date-picker>
        <el-button size="small" @click="findinfo()" type="primary"
          >查询</el-button
        >
      </el-form>
    </div>
    <el-divider></el-divider>

    <ht-table
      @load="loadData"
      :data="data"
      :pageResult="pageResult"
      :selection="true"
      :show-export="false"
      :show-custom-column="false"
      ref="htTable"
      :default-sorter="[{direction: 'DESC',property: 'id_'}]"
    >
      <template v-slot:toolbar>
        <div style="display: flex;">
          <el-button
            size="small"
            @click="showDialog()"
            icon="icon-withdraw"
            type="primary"
            plain
            >返回</el-button
          >
        </div>
      </template>
      <ht-table-column
        prop="rummager"
        label="检查人"
        :sortable="true"
        :show-overflow-tooltip="true"
      >
      </ht-table-column>
      <ht-table-column
        prop="checkDate"
        label="检查日期"
        :sortable="true"
        :show-overflow-tooltip="true"
      >
      </ht-table-column>

      <ht-table-column
        prop="noteTaker"
        label="记录人"
        :sortable="true"
        :show-overflow-tooltip="true"
      >
      </ht-table-column>

      <ht-table-column
        prop="weather"
        label="天气"
        :filters="getDictData('ty-tq')"
        :show-overflow-tooltip="true"
      >
        <template v-slot="{row}">
          <el-tag>{{ getDictName('ty-tq', row.weather) }}</el-tag>
        </template>
      </ht-table-column>

      <ht-table-column
        prop="evaluateValue"
        label="总体评价"
        :sortable="true"
        :show-overflow-tooltip="true"
      >
      </ht-table-column>
    </ht-table>
  </div>
</template>

<script>
export default {
  data() {
    return {
      data: [],
      searchForm: {},
      pageResult: {
        page: 1,
        pageSize: 20,
        total: 0
      },
      row: ''
    }
  },
  methods: {
    uniqueFunc(arr, uniId) {
      const res = new Map()
      return arr.filter(
        item => !res.has(item[uniId]) && res.set(item[uniId], 1)
      )
    },
    findinfo() {
      typeof this.$refs.filterTable !== 'undefined' && this.$refs.filterTable.clearFilter()
      let query = []
      let params = {routeId: this.searchForm.routeId}
      let search = {
        rummager: this.searchForm.rummager,
        tunnel_id_: this.row.id,
        checkDate: this.searchForm.checkDate
      }
      for (let i in search) {
        if (search[i]) {
          query.push({
            group: 'advance',
            operation: 'LIKE',
            property: i,
            relation: 'AND',
            value: search[i]
          })
        }
      }
      query = this.uniqueFunc(query, 'property')
      let data = {
        pageBean: {
          page: 1,
          pageSize: 20,
          showTotal: true
        },
        querys: query,
        params: params
      }
      this.topQuery = query
      this.$http.post('${form}/tunnelOftenCheck/v1/getJson', data).then(res => {
        console.log(res, '11')
        let response = res.data
        this.data = response.rows
        this.pageResult = {
          page: response.page,
          pageSize: response.pageSize,
          total: response.total
        }
      })
    },
    loadData(param, cb, tree) {
      if (this.row == '') {
        this.row = this.$route.params.row
        console.log(this.row, 'bp')
      }
      param.querys = [
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'tunnel_id_',
          relation: 'AND',
          value: this.row.id
        }
      ]
      if (typeof this.topQuery !== 'undefined' && this.topQuery.length !== 0) {
        param.querys = typeof param.querys !== 'undefined' ? param.querys : []
        this.topQuery.forEach(item => {
          param.querys.push(item)
        })
        param.querys = this.uniqueFunc(param.querys, 'property')
      }
      this.$http
        .post('${form}/tunnelOftenCheck/v1/getJson', param)
        .then(
          resp => {
            let response = resp.data
            this.data = response.rows
            this.pageResult = {
              page: response.page,
              pageSize: response.pageSize,
              total: response.total
            }
          },
          error => {
            reject(error)
          }
        )
        .finally(() => {
          if (cb) {
            cb()
          }
        })
    },
    showDialog() {
      this.$router.go(-1)
    }
  }
}
</script>

<style lang="scss" scoped>
.box {
  padding: 10px;
}
// /deep/ .el-main {
//   .el-table {
//     height: 745px !important;
//   }
// }
.el-dialog__header {
  border-bottom: 1px solid #eee;
}
/deep/ .el-date-editor.el-input,
.el-date-editor.el-input__inner {
  width: 100%;
}
/deep/.el-form-item__label {
  width: 100px;
}
.is-required:before {
  margin-right: 0;
}
/deep/.el-form-item__content {
  flex: 1;
  margin-left: 0 !important;
}
/deep/ .el-form-item__content .inputs {
  width: 100%;
}
/deep/ .el-select {
  width: 100%;
}
/deep/.el-dialog::-webkit-scrollbar {
  display: none;
}
/deep/.el-divider--horizontal {
  height: 10px;
  margin: 0 !important;
  position: absolute;
  left: 0;
}
/deep/.ht-table-panel {
  padding-top: 20px;
  height: calc(100% - 7%);
  overflow: hidden;
  background: #fff;
  display: flex;
  flex-direction: column;
  justify-content: space-between;
}
/deep/.ht-quick__search {
  margin-bottom: 10px;
}
/deep/.ht-table {
  height: calc(100% - 4vw) !important;
  max-height: calc(100% - 4vw) !important;
}
/deep/.pagination-panel {
  padding: 10px 0 0 0;
}
.searchTop > div {
  max-width: 200px;
}
</style>
